pub enum ParserError {
ReadlineError(String),
ReadsizeError(i64),
StateError(String),
TypeTokenError(char),
SizeExceededError,
}Expand description
Error enumeration used when a parsing error occurs
Variants
ReadlineError(String)
Error occured when reading a simple string that should end in \r\n
ReadsizeError(i64)
Error when an invalid size is read
StateError(String)
An internal state machine error, this should not happen, please report if it does!
TypeTokenError(char)
Next byte read was not a type token
SizeExceededError
Size limit hit